# koffie
Lightweight and minimalist framework for python web app

<p align="center">
<img src="koffie-logo.png" alt="koffie Logo" height="200"/>
</p>

## Installation
Install using ```pip```:
```sh
$ pip install koffie
```

## TIPS
```sh
cd development
pipenv install
CFLAGS="-I /usr/local/include -L /usr/local/lib" pipenv run python setup.py build_ext --inplace

```